@@ -2,6 +2,10 @@ import pytest
 
 import pipewrench
 import pipewrench.test.testobjs as testobjs
+import logging
+LOGLVL = logging.DEBUG
+
+logging.basicConfig(level=LOGLVL, format='%(asctime)s %(name)s %(levelname)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
 
 @pytest.fixture(scope = 'class')
 def pipefitting():
@@ -15,6 +19,14 @@ def filter():
 def screen():
 	return testobjs.TScreen()
 	
+@pytest.fixture()
+def retryscreen():
+	return pipewrench.RetryScreen(slideTime = 1)
+	
+@pytest.fixture()
+def retryfilter():
+	return testobjs.TFilterRetry()
+	
 class Test_PipeFitting(object):
 	def test_addFilter(self, pipefitting, filter):
 		pipefitting.addFilter(filter)
@@ -37,4 +49,14 @@ class Test_PipeFitting(object):
 		
 	def test_Step(self, pipefitting):
 		for msg in pipefitting.Step(1):
-			print msg
\ No newline at end of file
+			print msg
+			
+	
+class Test_Retry(object):
+	def test_addObjs(self, retryfilter, retryscreen, pipefitting):
+		pipefitting.addFilter(retryfilter)
+		pipefitting.addScreen(retryscreen, True)
+		
+	def test_Retry(self, pipefitting):
+		msg = pipefitting.Process(0)
+		assert msg == 4
