@@ -13,4 +13,11 @@ class TFilter(pipeline.Filter):
 		if msg > 3:
 			self.msg.StopProcessing = True
 		return msg
-		
\ No newline at end of file
+		
+		
+class TFilterRetry(pipeline.Filter):
+	def Execute(self, msg):
+		msg = msg + 1
+		if msg < 5:
+			self.msg.Retry = True
+		return msg
\ No newline at end of file
